@@ -1,5 +1,4 @@
-#ifndef __MAPNIK_VECTOR_TILE_DATASOURCE_PBF_H__
-#define __MAPNIK_VECTOR_TILE_DATASOURCE_PBF_H__
+#pragma once
 
 // mapnik
 #include <mapnik/box2d.hpp>
@@ -23,9 +22,9 @@ class tile_datasource_pbf : public datasource
 {
 public:
     tile_datasource_pbf(protozero::pbf_reader const& layer,
-                    unsigned x,
-                    unsigned y,
-                    unsigned z,
+                    std::uint64_t x,
+                    std::uint64_t y,
+                    std::uint64_t z,
                     bool use_tile_extent = false);
     virtual ~tile_datasource_pbf();
     datasource::datasource_t type() const;
@@ -43,9 +42,9 @@ private:
     mutable bool attributes_added_;
     mutable bool valid_layer_;
     protozero::pbf_reader layer_;
-    unsigned x_;
-    unsigned y_;
-    unsigned z_;
+    std::uint64_t x_;
+    std::uint64_t y_;
+    std::uint64_t z_;
     std::uint32_t tile_size_;
     mutable bool extent_initialized_;
     mutable mapnik::box2d<double> extent_;
@@ -68,5 +67,3 @@ private:
 #if !defined(MAPNIK_VECTOR_TILE_LIBRARY)
 #include "vector_tile_datasource_pbf.ipp"
 #endif
-
-#endif // __MAPNIK_VECTOR_TILE_DATASOURCE_PBF_H__
