@@ -6,22 +6,34 @@
 #include <mapnik/util/noncopyable.hpp>
 #include <mapnik/proj_transform.hpp>
 #include <mapnik/view_transform.hpp>
-#include <mapnik/geometry_envelope.hpp>
+#include <mapnik/geometry.hpp>
 
-#include "clipper.hpp"
+#include <mapnik/version.hpp>
+#if MAPNIK_VERSION >= 300100
+#include <mapnik/geometry/envelope.hpp>
+#else
+#include <mapnik/geometry_envelope.hpp>
+#endif
+
+// mapbox
+#include <mapbox/geometry/geometry.hpp>
 
 #pragma GCC diagnostic push
 #include <mapnik/warning_ignore.hpp>
+#include "boost_geometry_adapters.hpp"
 #include <boost/geometry/core/coordinate_type.hpp>
 #include <boost/geometry/core/access.hpp>
 #pragma GCC diagnostic pop
 
+#include <memory>
+
 namespace mapnik {
 
 namespace vector_tile_impl {
 
-static constexpr double coord_max = static_cast<double>(ClipperLib::hiRange);
-static constexpr double coord_min = -1 * static_cast<double>(ClipperLib::hiRange);
+static constexpr std::int64_t hiRange = 0x3FFFFFFFFFFFFFFFLL;
+static constexpr double coord_max = static_cast<double>(hiRange);
+static constexpr double coord_min = -1 * static_cast<double>(hiRange);
 
 struct vector_tile_strategy
 {
@@ -95,12 +107,12 @@ struct vector_tile_strategy_proj
 template <typename T>
 struct geom_out_visitor
 {
-    mapnik::geometry::geometry<T> geom;
+    std::shared_ptr<mapbox::geometry::geometry<T>> geom;
 
     template <typename T1>
     void operator() (T1 const& g)
     {
-        geom = mapnik::geometry::geometry<T>(g);
+        geom = std::make_shared<mapbox::geometry::geometry<T>>(mapbox::geometry::geometry<T>(g));
     }
 };
 
@@ -125,7 +137,7 @@ struct transform_visitor
         {
             return;
         }
-        mapnik::geometry::point<std::int64_t> new_geom;
+        mapbox::geometry::point<std::int64_t> new_geom;
         if (!tr_.apply(geom,new_geom))
         {
             return;
@@ -135,11 +147,11 @@ struct transform_visitor
 
     inline void operator() (mapnik::geometry::multi_point<double> const& geom)
     {
-        mapnik::geometry::multi_point<std::int64_t> new_geom;
+        mapbox::geometry::multi_point<std::int64_t> new_geom;
         new_geom.reserve(geom.size());
         for (auto const& pt : geom)
         {
-            mapnik::geometry::point<std::int64_t> pt2;
+            mapbox::geometry::point<std::int64_t> pt2;
             if (target_clipping_extent_.intersects(pt.x, pt.y) && tr_.apply(pt,pt2))
             {
                 new_geom.push_back(std::move(pt2));
@@ -159,11 +171,11 @@ struct transform_visitor
         {
             return;
         }
-        mapnik::geometry::line_string<std::int64_t> new_geom;
+        mapbox::geometry::line_string<std::int64_t> new_geom;
         new_geom.reserve(geom.size());
         for (auto const& pt : geom)
         {
-            mapnik::geometry::point<std::int64_t> pt2;
+            mapbox::geometry::point<std::int64_t> pt2;
             if (tr_.apply(pt,pt2))
             {
                 new_geom.push_back(std::move(pt2));
@@ -174,17 +186,17 @@ struct transform_visitor
 
     inline void operator() (mapnik::geometry::multi_line_string<double> const& geom)
     {
-        mapnik::geometry::multi_line_string<std::int64_t> new_geom;
+        mapbox::geometry::multi_line_string<std::int64_t> new_geom;
         new_geom.reserve(geom.size());
         for (auto const& line : geom)
         {
             mapnik::box2d<double> line_bbox = mapnik::geometry::envelope(line);
             if (!target_clipping_extent_.intersects(line_bbox)) continue;
-            mapnik::geometry::line_string<std::int64_t> new_line;
+            mapbox::geometry::line_string<std::int64_t> new_line;
             new_line.reserve(line.size());
             for (auto const& pt : line)
             {
-                mapnik::geometry::point<std::int64_t> pt2;
+                mapbox::geometry::point<std::int64_t> pt2;
                 if (tr_.apply(pt,pt2))
                 {
                     new_line.push_back(std::move(pt2));
@@ -206,16 +218,18 @@ struct transform_visitor
         {
             return;
         }
-        mapnik::geometry::polygon<std::int64_t> new_geom;
-        new_geom.exterior_ring.reserve(geom.exterior_ring.size());
+        mapbox::geometry::polygon<std::int64_t> new_geom;
+        mapbox::geometry::linear_ring<std::int64_t> exterior_ring;
+        exterior_ring.reserve(geom.exterior_ring.size());
         for (auto const& pt : geom.exterior_ring)
         {
-            mapnik::geometry::point<std::int64_t> pt2;
+            mapbox::geometry::point<std::int64_t> pt2;
             if (tr_.apply(pt,pt2))
             {
-                new_geom.exterior_ring.push_back(std::move(pt2));
+                exterior_ring.push_back(std::move(pt2));
             }
         }
+        new_geom.push_back(std::move(exterior_ring));
         for (auto const& ring : geom.interior_rings)
         {
             mapnik::box2d<double> ring_bbox = mapnik::geometry::envelope(static_cast<mapnik::geometry::line_string<double> const&>(ring));
@@ -223,24 +237,24 @@ struct transform_visitor
             {
                 continue;
             }
-            mapnik::geometry::linear_ring<std::int64_t> new_ring;
+            mapbox::geometry::linear_ring<std::int64_t> new_ring;
             new_ring.reserve(ring.size());
             for (auto const& pt : ring)
             {
-                mapnik::geometry::point<std::int64_t> pt2;
+                mapbox::geometry::point<std::int64_t> pt2;
                 if (tr_.apply(pt,pt2))
                 {
                     new_ring.push_back(std::move(pt2));
                 }
             }
-            new_geom.interior_rings.push_back(std::move(new_ring));
+            new_geom.push_back(std::move(new_ring));
         }
         return next_(new_geom);
     }
 
     inline void operator() (mapnik::geometry::multi_polygon<double> const& geom)
     {
-        mapnik::geometry::multi_polygon<std::int64_t> new_geom;
+        mapbox::geometry::multi_polygon<std::int64_t> new_geom;
         new_geom.reserve(geom.size());
         for (auto const& poly : geom)
         {
@@ -249,16 +263,18 @@ struct transform_visitor
             {
                 continue;
             }
-            mapnik::geometry::polygon<std::int64_t> new_poly;
-            new_poly.exterior_ring.reserve(poly.exterior_ring.size());
+            mapbox::geometry::polygon<std::int64_t> new_poly;
+            mapbox::geometry::linear_ring<std::int64_t> exterior_ring;
+            exterior_ring.reserve(poly.exterior_ring.size());
             for (auto const& pt : poly.exterior_ring)
             {
-                mapnik::geometry::point<std::int64_t> pt2;
+                mapbox::geometry::point<std::int64_t> pt2;
                 if (tr_.apply(pt,pt2))
                 {
-                    new_poly.exterior_ring.push_back(std::move(pt2));
+                    exterior_ring.push_back(std::move(pt2));
                 }
             }
+            new_poly.push_back(std::move(exterior_ring));
             for (auto const& ring : poly.interior_rings)
             {
                 mapnik::box2d<double> ring_bbox = mapnik::geometry::envelope(static_cast<mapnik::geometry::line_string<double> const&>(ring));
@@ -266,17 +282,17 @@ struct transform_visitor
                 {
                     continue;
                 }
-                mapnik::geometry::linear_ring<std::int64_t> new_ring;
+                mapbox::geometry::linear_ring<std::int64_t> new_ring;
                 new_ring.reserve(ring.size());
                 for (auto const& pt : ring)
                 {
-                    mapnik::geometry::point<std::int64_t> pt2;
+                    mapbox::geometry::point<std::int64_t> pt2;
                     if (tr_.apply(pt,pt2))
                     {
                         new_ring.push_back(std::move(pt2));
                     }
                 }
-                new_poly.interior_rings.push_back(std::move(new_ring));
+                new_poly.push_back(std::move(new_ring));
             }
             new_geom.push_back(std::move(new_poly));
         }
