@@ -43,11 +43,11 @@ TEST_CASE("decode simple polygon - scale 2")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, 2.0, 2.0);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 2.0, 2.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 5,-5 5,-5 0,0 0))");
@@ -56,7 +56,7 @@ TEST_CASE("decode simple polygon - scale 2")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 2.0, 2.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 5,-5 5,-5 0,0 0))");
@@ -86,11 +86,11 @@ TEST_CASE("decode simple polygon - scale 2 - int64 decode")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<std::int64_t> geoms = feature_to_pbf_geometry<std::int64_t>(feature_string, 2.0, 2.0);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<std::int64_t>(geoms, feature.type(), 1, 0.0, 0.0, 2.0, 2.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 5,-5 5,-5 0,0 0))");
@@ -99,7 +99,7 @@ TEST_CASE("decode simple polygon - scale 2 - int64 decode")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<std::int64_t>(geoms, feature.type(), 2, 0.0, 0.0, 2.0, 2.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 5,-5 5,-5 0,0 0))");
@@ -129,11 +129,11 @@ TEST_CASE("decode simple polygon - scale 3.214")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, 3.214, 3.214);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 3.214, 3.214);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 3.11138767890479,-3.11138767890479 3.11138767890479,-3.11138767890479 0,0 0))");
@@ -142,7 +142,7 @@ TEST_CASE("decode simple polygon - scale 3.214")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 3.214, 3.214);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 3.11138767890479,-3.11138767890479 3.11138767890479,-3.11138767890479 0,0 0))");
@@ -172,11 +172,11 @@ TEST_CASE("decode simple polygon - scale 3.214 - int64 decode")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<std::int64_t> geoms = feature_to_pbf_geometry<std::int64_t>(feature_string, 3.214, 3.214);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<std::int64_t>(geoms, feature.type(), 1, 0.0, 0.0, 3.214, 3.214);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 3,-3 3,-3 0,0 0))");
@@ -185,7 +185,7 @@ TEST_CASE("decode simple polygon - scale 3.214 - int64 decode")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<std::int64_t>(geoms, feature.type(), 2, 0.0, 0.0, 3.214, 3.214);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 3,-3 3,-3 0,0 0))");
@@ -215,11 +215,11 @@ TEST_CASE("decode simple polygon - scale 0.46")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, 0.46, 0.46);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 0.46, 0.46);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 21.7391304347826,-21.7391304347826 21.7391304347826,-21.7391304347826 0,0 0))");
@@ -228,7 +228,7 @@ TEST_CASE("decode simple polygon - scale 0.46")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 0.46, 0.46);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 21.7391304347826,-21.7391304347826 21.7391304347826,-21.7391304347826 0,0 0))");
@@ -258,11 +258,11 @@ TEST_CASE("decode simple polygon - scale 0.46 - int64 decode")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<std::int64_t> geoms = feature_to_pbf_geometry<std::int64_t>(feature_string, 0.46, 0.46);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<std::int64_t>(geoms, feature.type(), 1, 0.0, 0.0, 0.46, 0.46);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 22,-22 22,-22 0,0 0))");
@@ -271,7 +271,7 @@ TEST_CASE("decode simple polygon - scale 0.46 - int64 decode")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<std::int64_t>(geoms, feature.type(), 2, 0.0, 0.0, 0.46, 0.46);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 22,-22 22,-22 0,0 0))");
@@ -301,11 +301,11 @@ TEST_CASE("decode simple polygon - inverted y axis")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, 1.0, -1.0);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, -1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,-10 0,-10 -10,0 -10,0 0))");
@@ -314,7 +314,7 @@ TEST_CASE("decode simple polygon - inverted y axis")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, -1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,-10 0,-10 -10,0 -10,0 0))");
@@ -344,11 +344,11 @@ TEST_CASE("decode simple polygon - inverted x axis")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, -1.0, 1.0);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, -1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,10 0,10 10,0 10,0 0))");
@@ -357,7 +357,7 @@ TEST_CASE("decode simple polygon - inverted x axis")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, -1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,10 0,10 10,0 10,0 0))");
@@ -387,11 +387,11 @@ TEST_CASE("decode simple polygon - inverted x axis and y axis")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, -1.0, -1.0);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, -1.0, -1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 -10,10 -10,10 0,0 0))");
@@ -400,7 +400,7 @@ TEST_CASE("decode simple polygon - inverted x axis and y axis")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, -1.0, -1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,0 -10,10 -10,10 0,0 0))");
@@ -449,11 +449,11 @@ TEST_CASE("decode simple polygon with hole - invert y axis")
     feature.add_geometry(15);
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string, 1.0, -1.0);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, -1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,-10 0,-10 -10,0 -10,0 0),(-7 -7,-7 -3,-3 -3,-3 -7,-7 -7))");
@@ -462,7 +462,7 @@ TEST_CASE("decode simple polygon with hole - invert y axis")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, -1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "POLYGON((0 0,-10 0,-10 -10,0 -10,0 0),(-7 -7,-7 -3,-3 -3,-3 -7,-7 -7))");
