@@ -3,8 +3,8 @@
 // mapnik vector tile
 #include "vector_tile_geometry_encoder_pbf.hpp"
 
-// mapnik
-#include <mapnik/geometry.hpp>
+// mapbox
+#include <mapbox/geometry/geometry.hpp>
 
 // protozero
 #include <protozero/pbf_writer.hpp>
@@ -22,12 +22,14 @@
 
 TEST_CASE("encoding pbf simple polygon")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(-10,10);
-    p0.exterior_ring.add_coord(-10,0);
-    p0.exterior_ring.add_coord(0,0);
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    r0.emplace_back(-10,10);
+    r0.emplace_back(-10,0);
+    r0.emplace_back(0,0);
+    p0.push_back(r0);
     
     std::int32_t x = 0;
     std::int32_t y = 0;
@@ -63,13 +65,15 @@ TEST_CASE("encoding pbf simple polygon")
 
 TEST_CASE("encoding pbf simple polygon -- geometry")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(-10,10);
-    p0.exterior_ring.add_coord(-10,0);
-    p0.exterior_ring.add_coord(0,0);
-    mapnik::geometry::geometry<std::int64_t> geom(p0);
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    r0.emplace_back(-10,10);
+    r0.emplace_back(-10,0);
+    r0.emplace_back(0,0);
+    p0.push_back(r0);
+    mapbox::geometry::geometry<std::int64_t> geom(p0);
     
     std::int32_t x = 0;
     std::int32_t y = 0;
@@ -105,19 +109,21 @@ TEST_CASE("encoding pbf simple polygon -- geometry")
 
 TEST_CASE("encoding pbf simple polygon with hole")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(-10,10);
-    p0.exterior_ring.add_coord(-10,0);
-    p0.exterior_ring.add_coord(0,0);
-    mapnik::geometry::linear_ring<std::int64_t> hole;
-    hole.add_coord(-7,7);
-    hole.add_coord(-3,7);
-    hole.add_coord(-3,3);
-    hole.add_coord(-7,3);
-    hole.add_coord(-7,7);
-    p0.add_hole(std::move(hole));
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    r0.emplace_back(-10,10);
+    r0.emplace_back(-10,0);
+    r0.emplace_back(0,0);
+    p0.push_back(r0);
+    mapbox::geometry::linear_ring<std::int64_t> hole;
+    hole.emplace_back(-7,7);
+    hole.emplace_back(-3,7);
+    hole.emplace_back(-3,3);
+    hole.emplace_back(-7,3);
+    hole.emplace_back(-7,7);
+    p0.push_back(std::move(hole));
 
     std::int32_t x = 0;
     std::int32_t y = 0;
@@ -174,7 +180,7 @@ TEST_CASE("encoding pbf simple polygon with hole")
 
 TEST_CASE("encoding pbf empty polygon")
 {
-    mapnik::geometry::polygon<std::int64_t> p;
+    mapbox::geometry::polygon<std::int64_t> p;
     std::int32_t x = 0;
     std::int32_t y = 0;
     std::string feature_str;
@@ -189,38 +195,42 @@ TEST_CASE("encoding pbf empty polygon")
 
 TEST_CASE("encoding pbf multi polygons with holes")
 {
-    mapnik::geometry::multi_polygon<std::int64_t> mp;
+    mapbox::geometry::multi_polygon<std::int64_t> mp;
     {
-        mapnik::geometry::polygon<std::int64_t> p0;
-        p0.exterior_ring.add_coord(0,0);
-        p0.exterior_ring.add_coord(0,10);
-        p0.exterior_ring.add_coord(-10,10);
-        p0.exterior_ring.add_coord(-10,0);
-        p0.exterior_ring.add_coord(0,0);
-        mapnik::geometry::linear_ring<std::int64_t> hole;
-        hole.add_coord(-7,7);
-        hole.add_coord(-3,7);
-        hole.add_coord(-3,3);
-        hole.add_coord(-7,3);
-        hole.add_coord(-7,7);
-        p0.add_hole(std::move(hole));
+        mapbox::geometry::polygon<std::int64_t> p0;
+        mapbox::geometry::linear_ring<std::int64_t> r0;
+        r0.emplace_back(0,0);
+        r0.emplace_back(0,10);
+        r0.emplace_back(-10,10);
+        r0.emplace_back(-10,0);
+        r0.emplace_back(0,0);
+        p0.push_back(std::move(r0));
+        mapbox::geometry::linear_ring<std::int64_t> hole;
+        hole.emplace_back(-7,7);
+        hole.emplace_back(-3,7);
+        hole.emplace_back(-3,3);
+        hole.emplace_back(-7,3);
+        hole.emplace_back(-7,7);
+        p0.push_back(std::move(hole));
         mp.push_back(p0);
     }
     // yeah so its the same polygon -- haters gonna hate.
     {
-        mapnik::geometry::polygon<std::int64_t> p0;
-        p0.exterior_ring.add_coord(0,0);
-        p0.exterior_ring.add_coord(0,10);
-        p0.exterior_ring.add_coord(-10,10);
-        p0.exterior_ring.add_coord(-10,0);
-        p0.exterior_ring.add_coord(0,0);
-        mapnik::geometry::linear_ring<std::int64_t> hole;
-        hole.add_coord(-7,7);
-        hole.add_coord(-3,7);
-        hole.add_coord(-3,3);
-        hole.add_coord(-7,3);
-        hole.add_coord(-7,7);
-        p0.add_hole(std::move(hole));
+        mapbox::geometry::polygon<std::int64_t> p0;
+        mapbox::geometry::linear_ring<std::int64_t> r0;
+        r0.emplace_back(0,0);
+        r0.emplace_back(0,10);
+        r0.emplace_back(-10,10);
+        r0.emplace_back(-10,0);
+        r0.emplace_back(0,0);
+        p0.push_back(std::move(r0));
+        mapbox::geometry::linear_ring<std::int64_t> hole;
+        hole.emplace_back(-7,7);
+        hole.emplace_back(-3,7);
+        hole.emplace_back(-3,3);
+        hole.emplace_back(-7,3);
+        hole.emplace_back(-7,7);
+        p0.push_back(std::move(hole));
         mp.push_back(p0);
     }
 
@@ -321,41 +331,45 @@ TEST_CASE("encoding pbf multi polygons with holes")
 
 TEST_CASE("encoding pbf multi polygons with holes -- geometry type")
 {
-    mapnik::geometry::multi_polygon<std::int64_t> mp;
+    mapbox::geometry::multi_polygon<std::int64_t> mp;
     {
-        mapnik::geometry::polygon<std::int64_t> p0;
-        p0.exterior_ring.add_coord(0,0);
-        p0.exterior_ring.add_coord(0,10);
-        p0.exterior_ring.add_coord(-10,10);
-        p0.exterior_ring.add_coord(-10,0);
-        p0.exterior_ring.add_coord(0,0);
-        mapnik::geometry::linear_ring<std::int64_t> hole;
-        hole.add_coord(-7,7);
-        hole.add_coord(-3,7);
-        hole.add_coord(-3,3);
-        hole.add_coord(-7,3);
-        hole.add_coord(-7,7);
-        p0.add_hole(std::move(hole));
+        mapbox::geometry::polygon<std::int64_t> p0;
+        mapbox::geometry::linear_ring<std::int64_t> r0;
+        r0.emplace_back(0,0);
+        r0.emplace_back(0,10);
+        r0.emplace_back(-10,10);
+        r0.emplace_back(-10,0);
+        r0.emplace_back(0,0);
+        p0.push_back(std::move(r0));
+        mapbox::geometry::linear_ring<std::int64_t> hole;
+        hole.emplace_back(-7,7);
+        hole.emplace_back(-3,7);
+        hole.emplace_back(-3,3);
+        hole.emplace_back(-7,3);
+        hole.emplace_back(-7,7);
+        p0.push_back(std::move(hole));
         mp.push_back(p0);
     }
     // yeah so its the same polygon -- haters gonna hate.
     {
-        mapnik::geometry::polygon<std::int64_t> p0;
-        p0.exterior_ring.add_coord(0,0);
-        p0.exterior_ring.add_coord(0,10);
-        p0.exterior_ring.add_coord(-10,10);
-        p0.exterior_ring.add_coord(-10,0);
-        p0.exterior_ring.add_coord(0,0);
-        mapnik::geometry::linear_ring<std::int64_t> hole;
-        hole.add_coord(-7,7);
-        hole.add_coord(-3,7);
-        hole.add_coord(-3,3);
-        hole.add_coord(-7,3);
-        hole.add_coord(-7,7);
-        p0.add_hole(std::move(hole));
+        mapbox::geometry::polygon<std::int64_t> p0;
+        mapbox::geometry::linear_ring<std::int64_t> r0;
+        r0.emplace_back(0,0);
+        r0.emplace_back(0,10);
+        r0.emplace_back(-10,10);
+        r0.emplace_back(-10,0);
+        r0.emplace_back(0,0);
+        p0.push_back(std::move(r0));
+        mapbox::geometry::linear_ring<std::int64_t> hole;
+        hole.emplace_back(-7,7);
+        hole.emplace_back(-3,7);
+        hole.emplace_back(-3,3);
+        hole.emplace_back(-7,3);
+        hole.emplace_back(-7,7);
+        p0.push_back(std::move(hole));
         mp.push_back(p0);
     }
-    mapnik::geometry::geometry<std::int64_t> geom(mp);
+    mapbox::geometry::geometry<std::int64_t> geom(mp);
 
     std::int32_t x = 0;
     std::int32_t y = 0;
@@ -454,7 +468,7 @@ TEST_CASE("encoding pbf multi polygons with holes -- geometry type")
 
 TEST_CASE("encoding pbf empty multi polygon")
 {
-    mapnik::geometry::multi_polygon<std::int64_t> mp;
+    mapbox::geometry::multi_polygon<std::int64_t> mp;
     std::int32_t x = 0;
     std::int32_t y = 0;
     std::string feature_str;
@@ -469,16 +483,18 @@ TEST_CASE("encoding pbf empty multi polygon")
 
 TEST_CASE("encoding pbf polygon with degenerate exterior ring full of repeated points")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
     // invalid exterior ring
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(0,10);
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    r0.emplace_back(0,10);
+    r0.emplace_back(0,10);
+    r0.emplace_back(0,10);
+    r0.emplace_back(0,10);
+    r0.emplace_back(0,10);
+    r0.emplace_back(0,10);
+    p0.push_back(std::move(r0));
 
     std::int32_t x = 0;
     std::int32_t y = 0;
@@ -494,10 +510,12 @@ TEST_CASE("encoding pbf polygon with degenerate exterior ring full of repeated p
 
 TEST_CASE("encoding pbf polygon with degenerate exterior ring")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
     // invalid exterior ring
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    p0.push_back(std::move(r0));
 
     std::int32_t x = 0;
     std::int32_t y = 0;
@@ -513,18 +531,20 @@ TEST_CASE("encoding pbf polygon with degenerate exterior ring")
 
 TEST_CASE("encoding pbf polygon with degenerate exterior ring and interior ring")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
     // invalid exterior ring
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    p0.push_back(std::move(r0));
     // invalid interior ring -- is counter clockwise
-    mapnik::geometry::linear_ring<std::int64_t> hole;
-    hole.add_coord(-7,7);
-    hole.add_coord(-3,7);
-    hole.add_coord(-3,3);
-    hole.add_coord(-7,3);
-    hole.add_coord(-7,7);
-    p0.add_hole(std::move(hole));
+    mapbox::geometry::linear_ring<std::int64_t> hole;
+    hole.emplace_back(-7,7);
+    hole.emplace_back(-3,7);
+    hole.emplace_back(-3,3);
+    hole.emplace_back(-7,3);
+    hole.emplace_back(-7,7);
+    p0.push_back(std::move(hole));
 
     // encoder should cull the exterior invalid ring, which triggers
     // the entire polygon to be culled.
@@ -542,17 +562,19 @@ TEST_CASE("encoding pbf polygon with degenerate exterior ring and interior ring"
 
 TEST_CASE("encoding pbf polygon with valid exterior ring but degenerate interior ring")
 {
-    mapnik::geometry::polygon<std::int64_t> p0;
-    p0.exterior_ring.add_coord(0,0);
-    p0.exterior_ring.add_coord(0,10);
-    p0.exterior_ring.add_coord(-10,10);
-    p0.exterior_ring.add_coord(-10,0);
-    p0.exterior_ring.add_coord(0,0);
+    mapbox::geometry::polygon<std::int64_t> p0;
+    mapbox::geometry::linear_ring<std::int64_t> r0;
+    r0.emplace_back(0,0);
+    r0.emplace_back(0,10);
+    r0.emplace_back(-10,10);
+    r0.emplace_back(-10,0);
+    r0.emplace_back(0,0);
+    p0.push_back(std::move(r0));
     // invalid interior ring
-    mapnik::geometry::linear_ring<std::int64_t> hole;
-    hole.add_coord(-7,7);
-    hole.add_coord(-3,7);
-    p0.add_hole(std::move(hole));
+    mapbox::geometry::linear_ring<std::int64_t> hole;
+    hole.emplace_back(-7,7);
+    hole.emplace_back(-3,7);
+    p0.push_back(std::move(hole));
 
     std::int32_t x = 0;
     std::int32_t y = 0;
