@@ -4,7 +4,6 @@
 // mapnik vector tile
 #include "vector_tile_geometry_decoder.hpp"
 
-template <typename T>
-mapnik::vector_tile_impl::GeometryPBF<T> feature_to_pbf_geometry(std::string const& feature_string, double scale_x = 1.0, double scale_y = 1.0);
+mapnik::vector_tile_impl::GeometryPBF feature_to_pbf_geometry(std::string const& feature_string);
 
 #endif // __MAPNIK_VECTOR_TILE_TEST_DECODING_UTIL_H__
