@@ -1,8 +1,8 @@
 #ifndef __MAPNIK_VECTOR_TILE_TEST_ENCODING_UTIL_H__
 #define __MAPNIK_VECTOR_TILE_TEST_ENCODING_UTIL_H__
 
-// mapnik
-#include <mapnik/geometry.hpp>
+// mapbox
+#include <mapbox/geometry/geometry.hpp>
 
 // libprotobuf
 #pragma GCC diagnostic push
@@ -11,6 +11,6 @@
 #include "vector_tile.pb.h"
 #pragma GCC diagnostic pop
 
-std::string compare_pbf(mapnik::geometry::geometry<std::int64_t> const& g, unsigned version);
+std::string compare_pbf(mapbox::geometry::geometry<std::int64_t> const& g, unsigned version);
 
 #endif // __MAPNIK_VECTOR_TILE_TEST_ENCODING_UTIL_H__
