@@ -70,7 +70,7 @@ mapnik::geometry::geometry<double> round_trip(mapnik::geometry::geometry<double>
     }
     protozero::pbf_reader feature_reader = layer_reader.get_message();
     int32_t geometry_type = mapnik::vector_tile_impl::Geometry_Type::UNKNOWN; 
-    std::pair<protozero::pbf_reader::const_uint32_iterator, protozero::pbf_reader::const_uint32_iterator> geom_itr;
+    mapnik::vector_tile_impl::GeometryPBF::pbf_itr geom_itr;
     while (feature_reader.next())
     {
         if (feature_reader.tag() == mapnik::vector_tile_impl::Feature_Encoding::GEOMETRY)
